Star Wars: The Old Republic | Log in
Description: Official site. BioWare and LucasArts bring you the next evolution in MMO Gameplay: Story.
Keywords: Star Wars, Star Wars Games, online game, mmo, mmorpg, rpg, information, BioWare, Bioware games, LucasArts, Lucasarts games, Star Wars The Old Republic, The Old Republic, Knights of the Old Republic MMO, KOTOR MMO, KOTOR, TOR, SWTOR, SWTOR MMO, Star Wars MMO, BioWare MMO, LucasArts MMO, massively multiplayer online game, massively multiplayer online role playing game

Play Now
En Fr De

# Log in to SWTOR.COM

Display Name:
Forgot your Display Name?
Password:
Forgot your SWTOR.COM password?
Security Key: (what is this?)
If you don't have a Security Key, you can leave this blank.

## Security Key Code

The security key code is the eight (8) digit number displayed on the security key, each number is unique and only valid for thirty (30) seconds.

On mobile security keys once you launch the application, the number is visible here:

On physical security keys, press the button and the number appears here:

## Serial Number

When you first associate the security key with your SWTOR account you will be asked to enter the serial number of the key.

Please ensure you take down this serial number and keep it safe as it may be required to remove the security key from the account. Then, you'll be prompted to enter an activation code here:

## Serial Number

The security key serial number identifies your unique Security Key.

On mobile security keys, the serial number is assigned to you when you set up your mobile security key. To view it, launch the app, click the "Information" icon, click "Security key information" and the number is visible here:

On physical security keys, the number is visible here on the back of the security key:

Don't have an account? Play Now!
Terms Archive | Privacy Policy | Terms of Service | FAQ | EUALA | Rules of Conduct | Online Safety | Contact Us
LucasArts, the LucasArts logo, STAR WARS and related properties are trademarks in the United States and/or in other countries of Lucasfilm Ltd. and/or its affiliates. © 2011-2012 Lucasfilm Entertainment Company Ltd. or Lucasfilm Ltd. All rights reserved. BioWare and the BioWare logo are trademarks of EA International (Studio and Publishing) Ltd. EA and the EA logo are trademarks of Electronic Arts Inc. All other trademarks are the property of their respective owners.

## You are about to leave this website...

This page is not meant to keep you from following the link you've clicked on. It is just a warning that you are about to leave this website. To go to this page, click the link below.

If you do not wish to follow this link, simply close this message.

The statements and opinions expressed on these websites are solely those of their respective authors and do not necessarily reflect the views, nor are they endorsed by Bioware, LucasArts, and its licensors do not guarantee the accuracy of, and are in no way responsible for any content on these websites, and the Star Wars: The Old Republic privacy policy does not apply to their information collection practices.

Close Continue